commit 21748d636854a20fe00e3970378ca1f1238f4367
Author: Florian Ernst <florian_ernst@gmx.net>
Date:   Sat Apr 2 20:17:34 2022 +0200

    Fix test error in C++ template syntax

diff --git a/debian/changelog b/debian/changelog
index b6ae7f5..54027d9 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -7,6 +7,9 @@ libvigraimpex (1.11.1+dfsg-9) UNRELEASED; urgency=medium
   * Fix Build issue with gcc-11
     Closes: #984049
 
+  [ Florian Ernst ]
+  * Fix test error in C++ template syntax. Closes: #984049
+
  -- Andreas Metzler <ametzler@debian.org>  Mon, 27 Dec 2021 13:18:05 +0100
 
 libvigraimpex (1.11.1+dfsg-8) unstable; urgency=medium
diff --git a/debian/patches/python_3.10_support.patch b/debian/patches/python_3.10_support.patch
new file mode 100644
index 0000000..06d6f7a
--- /dev/null
+++ b/debian/patches/python_3.10_support.patch
@@ -0,0 +1,46 @@
+Description: Add Python 3.10 support
+Author: Dominik Kutra
+Bug-Debian: https://bugs.debian.org/984049
+Origin: upstream, https://github.com/ukoethe/vigra/pull/501/files#diff-aebec2bf372cb2b63b5d8b26f9c5e12326ab46ce4f422cafad97aca761bc2c4d
+
+Index: libvigraimpex/vigranumpy/lib/arraytypes.py
+===================================================================
+--- libvigraimpex.orig/vigranumpy/lib/arraytypes.py
++++ libvigraimpex/vigranumpy/lib/arraytypes.py
+@@ -39,11 +39,17 @@ import sys
+ import copy
+ import numpy
+ import vigra.ufunc as ufunc
+-import collections
+ import vigra.vigranumpycore as vigranumpycore
+ 
+ from vigra.vigranumpycore import AxisType, AxisInfo, AxisTags
+ 
++try:
++    from collections.abc import Iterable
++except ImportError:
++    # Python 2.7
++    from collections import Iterable
++
++
+ if sys.version_info[0] > 2:
+     buffer = memoryview
+     xrange = range
+@@ -284,6 +290,8 @@ _constructArrayFromAxistags = vigranumpy
+ 
+ def _constructArrayFromOrder(cls, shape, dtype, order, init):
+     axistags = VigraArray.defaultAxistags(len(shape), order)
++    if hasattr(dtype, "type"):
++        dtype = dtype.type
+     return _constructArrayFromAxistags(cls, shape, dtype, axistags, init)
+ 
+ def _constructArrayFromArray(cls, obj, dtype, order, init, axistags):
+@@ -1262,7 +1270,7 @@ class VigraArray(numpy.ndarray):
+         try:
+             res = numpy.ndarray.__getitem__(self, index)
+         except:
+-            if not isinstance(index, collections.Iterable):
++            if not isinstance(index, Iterable):
+                 raise
+             #create temporary index without AxisInfor in order to use np.ndarray.__getitem__
+             tmpindex = [None if isinstance(x, AxisInfo) else x for x in index]
diff --git a/debian/patches/series b/debian/patches/series
index 8e6357c..a42a3f3 100644
--- a/debian/patches/series
+++ b/debian/patches/series
@@ -15,3 +15,4 @@
 48_sphinx4_error.diff
 c++17conf.patch
 # pythonexcept.patch
+python_3.10_support.patch
